## ----"setup", include=FALSE---------------------------------------------------
require("knitr")
opts_chunk$set(fig.width=4, fig.height=3)

## ----help-cci-----------------------------------------------------------------
library(scMultiSim)

scmultisim_help("cci")

## ----cci-network--------------------------------------------------------------
lig_params <- data.frame(
  target    = c(101, 102),
  regulator = c(103, 104),
  effect    = c(5.2, 5.9)
)

## -----------------------------------------------------------------------------
data(GRN_params_100)
set.seed(42)

options_ <- list(
  GRN = GRN_params_100,
  num.genes = 120,
  num.cells = 80,
  num.cifs = 20,
  cif.sigma = 0.2,
  tree = Phyla3(),
  intrinsic.noise = 0.5,
  cci = list(
    params = lig_params,
    max.neighbors = 4,
    grid.size = 13,
    cell.type.interaction = "random",
    step.size = 0.5
  )
)

results <- sim_true_counts(options_)

## ----plot-cell-loc, fig.width=4.5, fig.height=4-------------------------------
plot_cell_loc(results)

## ----print-cell-loc-----------------------------------------------------------
head(results$cci_locs)

## ----session-info-------------------------------------------------------------
sessionInfo()

